==> derby-0.0.5.tgz: package/lib/htmlParser.js <==
var attr, comment, endTag, startTag;
startTag = /^<(\w+)((?:\s+\w+(?:\s*=\s*(?:(?:"[^"]*")|(?:'[^']*')|[^>\s]+)?)?)*)\s*(\/?)>/;
endTag = /^<\/(\w+)[^>]*>/;
attr = /(\w+)(?:\s*(=)\s*(?:(?:"((?:\\.|[^"])*)")|(?:'((?:\\.|[^'])*)')|([^>\s]+))?)?/g;
comment = /<!--[\s\S]*?-->/g;
exports.parse = function(html, handler) {
  var chars, charsHandler, empty, endHandler, index, last, match, parseEndTag, parseStartTag, startHandler, text, _results;
  parseStartTag = function(tag, tagName, rest) {
    var attrs;
    attrs = {};
    rest.replace(attr, function(match, name, equals, attr0, attr1, attr2) {
      return attrs[name.toLowerCase()] = attr0 || attr1 || attr2 || (equals ? '' : null);
    });
    return startHandler(tag, tagName.toLowerCase(), attrs);
  };
  parseEndTag = function(tag, tagName) {
    return endHandler(tag, tagName.toLowerCase());
  };
  empty = function() {};
  charsHandler = (handler && handler.chars) || empty;
  startHandler = (handler && handler.start) || empty;
  endHandler = (handler && handler.end) || empty;
  html = html.replace(comment, '');
  _results = [];
  while (html) {
    last = html;
    chars = true;
    if (html[0] === '<') {
      if (html[1] === '/') {
        match = html.match(endTag);
        if (match) {
          html = html.substring(match[0].length);
          match[0].replace(endTag, parseEndTag);
          chars = false;
        }
      } else {
        match = html.match(startTag);
        if (match) {
          html = html.substring(match[0].length);
          match[0].replace(startTag, parseStartTag);
          chars = false;
        }
      }
    }
    if (chars) {
      index = html.indexOf('<');
      text = index < 0 ? html : html.substring(0, index);
      html = index < 0 ? '' : html.substring(index);
      if (text) {
        charsHandler(text);
      }
    }
    _results.push((function() {
      if (html === last) {
        throw 'Parse error: ' + html;
      }
    })());
  }
  return _results;
};

==> derby-0.0.8.tgz: package/lib/htmlParser.js <==
var attr, comment, endTag, startTag;
startTag = /^<(\w+)((?:\s+[^\s=\/>]+(?:\s*=\s*(?:(?:"[^"]*")|(?:'[^']*')|[^>\s]+)?)?)*)\s*(\/?)\s*>/;
endTag = /^<\/(\w+)[^>]*>/;
attr = /([^\s=]+)(?:\s*(=)\s*(?:(?:"((?:\\.|[^"])*)")|(?:'((?:\\.|[^'])*)')|([^>\s]+))?)?/g;
comment = /<!--[\s\S]*?-->/g;
exports.parse = function(html, handler) {
  var chars, charsHandler, empty, endHandler, index, last, match, parseEndTag, parseStartTag, startHandler, text, _results;
  if (handler == null) {
    handler = {};
  }
  parseStartTag = function(tag, tagName, rest) {
    var attrs;
    attrs = {};
    rest.replace(attr, function(match, name, equals, attr0, attr1, attr2) {
      return attrs[name.toLowerCase()] = attr0 || attr1 || attr2 || (equals ? '' : null);
    });
    return startHandler(tag, tagName.toLowerCase(), attrs);
  };
  parseEndTag = function(tag, tagName) {
    return endHandler(tag, tagName.toLowerCase());
  };
  empty = function() {};
  charsHandler = handler.chars || empty;
  startHandler = handler.start || empty;
  endHandler = handler.end || empty;
  html = html.replace(comment, '');
  _results = [];
  while (html) {
    last = html;
    chars = true;
    if (html[0] === '<') {
      if (html[1] === '/') {
        match = html.match(endTag);
        if (match) {
          html = html.substring(match[0].length);
          match[0].replace(endTag, parseEndTag);
          chars = false;
        }
      } else {
        match = html.match(startTag);
        if (match) {
          html = html.substring(match[0].length);
          match[0].replace(startTag, parseStartTag);
          chars = false;
        }
      }
    }
    if (chars) {
      index = html.indexOf('<');
      text = index < 0 ? html : html.substring(0, index);
      html = index < 0 ? '' : html.substring(index);
      if (text) {
        charsHandler(text);
      }
    }
    _results.push((function() {
      if (html === last) {
        throw 'Parse error: ' + html;
      }
    })());
  }
  return _results;
};
